package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.core.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.menu.domain.MenuCollectionDishes;
import com.bonus.canteen.core.menu.service.IMenuCollectionDishesService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 菜品收藏Controller
 * 
 * @author xsheng
 * @date 2025-04-20
 */
@Api(tags = "菜品收藏接口")
@RestController
@RequestMapping("/menu_collection_dishes")
public class MenuCollectionDishesController extends BaseController {
    @Autowired
    private IMenuCollectionDishesService menuCollectionDishesService;

    /**
     * 查询菜品收藏列表
     */
    @ApiOperation(value = "查询菜品收藏列表")
    //@RequiresPermissions("menu:dishes:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuCollectionDishes menuCollectionDishes) {
        startPage();
        List<MenuCollectionDishes> list = menuCollectionDishesService.selectMenuCollectionDishesList(menuCollectionDishes);
        return getDataTable(list);
    }

    /**
     * 导出菜品收藏列表
     */
    @ApiOperation(value = "导出菜品收藏列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:export")
    @SysLog(title = "菜品收藏", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出菜品收藏")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuCollectionDishes menuCollectionDishes) {
        List<MenuCollectionDishes> list = menuCollectionDishesService.selectMenuCollectionDishesList(menuCollectionDishes);
        ExcelUtil<MenuCollectionDishes> util = new ExcelUtil<MenuCollectionDishes>(MenuCollectionDishes.class);
        util.exportExcel(response, list, "菜品收藏数据");
    }

    /**
     * 获取菜品收藏详细信息
     */
    @ApiOperation(value = "获取菜品收藏详细信息")
    //@RequiresPermissions("menu:dishes:query")
    @GetMapping(value = "/{dishesId}")
    public AjaxResult getInfo(@PathVariable("dishesId") Long dishesId) {
        return success(menuCollectionDishesService.selectMenuCollectionDishesById(dishesId));
    }

    /**
     * 新增菜品收藏
     */
    @ApiOperation(value = "新增菜品收藏")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:add")
    @SysLog(title = "菜品收藏", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增菜品收藏")
    @PostMapping
    public AjaxResult add(@RequestBody MenuCollectionDishes menuCollectionDishes) {
        try {
            return toAjax(menuCollectionDishesService.insertMenuCollectionDishes(menuCollectionDishes));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改菜品收藏
     */
    @ApiOperation(value = "修改菜品收藏")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:edit")
    @SysLog(title = "菜品收藏", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改菜品收藏")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuCollectionDishes menuCollectionDishes) {
        try {
            return toAjax(menuCollectionDishesService.updateMenuCollectionDishes(menuCollectionDishes));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除菜品收藏
     */
    @ApiOperation(value = "删除菜品收藏")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:remove")
    @SysLog(title = "菜品收藏", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除菜品收藏")
	@PostMapping("/del/{dishesIds}")
    public AjaxResult remove(@PathVariable String[] dishesIds) {
        return toAjax(menuCollectionDishesService.deleteMenuCollectionDishesByIds(dishesIds));
    }
}
